@@ -8,16 +8,8 @@ This module was written by Matthias Cuntz while at Institut National de
 Recherche pour l'Agriculture, l'Alimentation et l'Environnement (INRAE), Nancy,
 France.
 
-Copyright (c) 2020-2021 Matthias Cuntz - mc (at) macu (dot) de
-
-Released under the MIT License; see LICENSE file for details.
-
-History:
-
-* Written Nov-Dec 2020 by Matthias Cuntz (mc (at) macu (dot) de)
-* Open new netcdf file, communicate via top widget, Jan 2021, Matthias Cuntz
-* Write coordinates and value on bottom of plotting canvas,
-  May 2021, Matthias Cuntz
+:copyright: Copyright 2020-2021 Matthias Cuntz - mc (at) macu (dot) de
+:license: MIT License, see LICENSE for details.
 
 .. moduleauthor:: Matthias Cuntz
 
@@ -25,6 +17,14 @@ The following classes are provided:
 
 .. autosummary::
    ncvContour
+
+History
+    * Written Nov-Dec 2020 by Matthias Cuntz (mc (at) macu (dot) de)
+    * Open new netcdf file, communicate via top widget,
+      Jan 2021, Matthias Cuntz
+    * Write coordinates and value on bottom of plotting canvas,
+      May 2021, Matthias Cuntz
+
 """
 from __future__ import absolute_import, division, print_function
 import sys
@@ -45,7 +45,7 @@ from .ncvmethods import set_dim_x, set_dim_y, set_dim_z
 from .ncvwidgets import add_checkbutton, add_combobox, add_entry, add_imagemenu
 from .ncvwidgets import add_spinbox, add_tooltip
 import matplotlib
-matplotlib.use('TkAgg')
+# matplotlib.use('TkAgg')
 from matplotlib import pyplot as plt
 # plt.style.use('seaborn-darkgrid')
 plt.style.use('seaborn-dark')
