@@ -9,16 +9,8 @@ This module was written by Matthias Cuntz while at Institut National de
 Recherche pour l'Agriculture, l'Alimentation et l'Environnement (INRAE), Nancy,
 France.
 
-Copyright (c) 2020-2021 Matthias Cuntz - mc (at) macu (dot) de
-
-Released under the MIT License; see LICENSE file for details.
-
-History:
-
-* Written Dec 2020-Jan 2021 by Matthias Cuntz (mc (at) macu (dot) de)
-* Open new netcdf file, communicate via top widget, Jan 2021, Matthias Cuntz
-* Write coordinates and value on bottom of plotting canvas,
-  May 2021, Matthias Cuntz
+:copyright: Copyright 2020-2021 Matthias Cuntz - mc (at) macu (dot) de
+:license: MIT License, see LICENSE for details.
 
 .. moduleauthor:: Matthias Cuntz
 
@@ -26,6 +18,17 @@ The following classes are provided:
 
 .. autosummary::
    ncvMap
+
+History
+    * Written Dec 2020-Jan 2021 by Matthias Cuntz (mc (at) macu (dot) de)
+    * Open new netcdf file, communicate via top widget,
+      Jan 2021, Matthias Cuntz
+    * Write coordinates and value on bottom of plotting canvas,
+      May 2021, Matthias Cuntz
+    * Larger pad for colorbar, Jun 2021, Matthias Cuntz
+    * Work with files without an unlimited (time) dimension (set_tstep),
+      Oct 2021, Matthias Cuntz
+
 """
 from __future__ import absolute_import, division, print_function
 import sys
@@ -46,7 +49,7 @@ from .ncvmethods import set_dim_lon, set_dim_lat, set_dim_var
 from .ncvwidgets import add_checkbutton, add_combobox, add_entry, add_imagemenu
 from .ncvwidgets import add_menu, add_scale, add_spinbox, add_tooltip
 import matplotlib as mpl
-mpl.use('TkAgg')
+# mpl.use('TkAgg')
 from matplotlib import pyplot as plt
 # plt.style.use('seaborn-darkgrid')
 plt.style.use('seaborn-dark')
@@ -950,12 +953,13 @@ class ncvMap(ttk.Frame):
         Sets the time dimension spinbox, sets the time step scale,
         write the time on top.
         """
-        self.vdval[self.iunlim].set(it)
-        self.tstepval.set(it)
-        try:
-            self.timelbl.set(np.around(self.time[it], 4))
-        except TypeError:
-            self.timelbl.set(self.time[it])
+        if self.dunlim:
+            self.vdval[self.iunlim].set(it)
+            self.tstepval.set(it)
+            try:
+                self.timelbl.set(np.around(self.time[it], 4))
+            except TypeError:
+                self.timelbl.set(self.time[it])
 
     def set_unlim(self, v):
         """
@@ -1239,7 +1243,7 @@ class ncvMap(ttk.Frame):
                     #     origin='upper', extent=self.img_extent,
                     #     transform=self.itrans)
                     self.cb = self.figure.colorbar(self.cc, fraction=0.05,
-                                                   shrink=0.75,
+                                                   shrink=0.75, pad=0.07,
                                                    extend=self.iextend)
                 except Exception:
                     estr  = 'Map pcolormesh: lon (' + vx + '), '
@@ -1257,7 +1261,7 @@ class ncvMap(ttk.Frame):
                         cmap=self.icmap, extend=self.iextend,
                         transform=self.itrans)
                     self.cb = self.figure.colorbar(self.cc, fraction=0.05,
-                                                   shrink=0.75)
+                                                   shrink=0.75, pad=0.07)
                     # self.cc, = self.axes.plot(yy, vv[0,:])
                 except Exception:
                     estr  = 'Map contourf: lon (' + vx + '), lat (' + vy + '),'
