@@ -15,30 +15,8 @@ This module was written by Matthias Cuntz while at Institut National de
 Recherche pour l'Agriculture, l'Alimentation et l'Environnement (INRAE), Nancy,
 France.
 
-Copyright (c) 2020-2021 Matthias Cuntz - mc (at) macu (dot) de
-
-Released under the MIT License; see LICENSE file for details.
-
-History:
-
-* Written Nov-Dec 2020 by Matthias Cuntz (mc (at) macu (dot) de)
-* Slice arrays with slice function rather than numpy.take,
-  Dec 2020, Matthias Cuntz
-* Moved individual get_slice? methods for x, y, y2, z as general get_slice
-  function to ncvutils, Dec 2020, Matthias Cuntz
-* Added convenience method get_slice_miss, Dec 2020, Matthias Cuntz
-* set_dim_lon, set_dim_lat, set_dim_var for Map panel,
-  Jan 2021, Matthias Cuntz
-* set latdim, londim to all on map var, determined in ncvMain,
-  Jan 2021, Matthias Cuntz
-* catch non numpy.dtype in set_miss, Jan 2021, Matthias Cuntz
-* catch variables that have only one string or similar,
-  Jan 2021, Matthias Cuntz
-* added tooltip to dimensions, Jan 2021, Matthias Cuntz
-* added analyse_netcdf from ncvmain, Jan 2021, Matthias Cuntz
-* use dlblval instead of dlbl to set dimension labels, Jan 2021, Matthias Cuntz
-* make self.time numpy's datetime64[ms] format, May 2021, Matthias Cuntz
-* add numpy's datetime64[ms] to missing values, May 2021, Matthias Cuntz
+:copyright: Copyright 2020-2021 Matthias Cuntz - mc (at) macu (dot) de
+:license: MIT License, see LICENSE for details.
 
 .. moduleauthor:: Matthias Cuntz
 
@@ -55,12 +33,40 @@ The following methods are provided:
    set_dim_y
    set_dim_y2
    set_dim_z
+
+History
+    * Written Nov-Dec 2020 by Matthias Cuntz (mc (at) macu (dot) de)
+    * Slice arrays with slice function rather than numpy.take,
+      Dec 2020, Matthias Cuntz
+    * Moved individual get_slice? methods for x, y, y2, z as general get_slice
+      function to ncvutils, Dec 2020, Matthias Cuntz
+    * Added convenience method get_slice_miss, Dec 2020, Matthias Cuntz
+    * set_dim_lon, set_dim_lat, set_dim_var for Map panel,
+      Jan 2021, Matthias Cuntz
+    * Set latdim, londim to all on map var, determined in ncvMain,
+      Jan 2021, Matthias Cuntz
+    * Catch non numpy.dtype in set_miss, Jan 2021, Matthias Cuntz
+    * Catch variables that have only one string or similar,
+      Jan 2021, Matthias Cuntz
+    * Added tooltip to dimensions, Jan 2021, Matthias Cuntz
+    * Added analyse_netcdf from ncvmain, Jan 2021, Matthias Cuntz
+    * Use dlblval instead of dlbl to set dimension labels,
+      Jan 2021, Matthias Cuntz
+    * Make self.time numpy's datetime64[ms] format, May 2021, Matthias Cuntz
+    * Add numpy's datetime64[ms] to missing values, May 2021, Matthias Cuntz
+    * Removed bug in detection of lon/lat (analyse_netcdf),
+      Oct 2021, Matthias Cuntz
+    * Identify lon/lat also by axis attributes x/y or X/Y (analyse_netcdf),
+      Oct 2021, Matthias Cuntz
+    * Do not default the unlimited dimension to 'all' if no lon/lat were found,
+      (get_dim_var) Oct 2021, Matthias Cuntz
+
 """
 from __future__ import absolute_import, division, print_function
 import tkinter as tk
 import numpy as np
 from .ncvutils import DIMMETHODS, get_slice, set_miss, spinbox_values
-from .ncvutils import SEPCHAR, vardim2var, zip_dim_name_length
+from .ncvutils import vardim2var, zip_dim_name_length
 import netCDF4 as nc
 # nc.default_fillvals but with keys as variables['var'].dtype
 nctypes = [ np.dtype(i) for i in nc.default_fillvals ]
@@ -226,7 +232,7 @@ def analyse_netcdf(self):
     # construct list of variable names with dimensions
     if self.time is not None:
         addt = [
-            self.tname + ' ' + SEPCHAR +
+            self.tname + ' ' +
             str(tuple(zip_dim_name_length(self.fi.variables[self.tvar])))]
         self.cols += addt
     ivars = []
@@ -235,7 +241,7 @@ def analyse_netcdf(self):
         ss = tuple(zip_dim_name_length(self.fi.variables[vv]))
         self.maxdim = max(self.maxdim, len(ss))
         ivars.append((vv, ss, len(ss)))
-    self.cols += sorted([ vv[0] + ' ' + SEPCHAR + str(vv[1])
+    self.cols += sorted([ vv[0] + ' ' + str(vv[1])
                           for vv in ivars ])
     #
     # search for lat/lon variables
@@ -321,7 +327,24 @@ def analyse_netcdf(self):
                     sunit = ''
                 if sunit.lower() == 'degrees_east':
                     self.lonvar = vv
-    # fourth sweep: same as first but units can be "degrees"
+    # fourth sweep: axis is 'Y' or 'y'
+    if not self.latvar:
+        for vv in self.fi.variables:
+            try:
+                saxis = self.fi.variables[vv].axis
+            except AttributeError:
+                saxis = ''
+            if saxis.lower() == 'y':
+                self.latvar = vv
+    if not self.lonvar:
+        for vv in self.fi.variables:
+            try:
+                saxis = self.fi.variables[vv].axis
+            except AttributeError:
+                saxis = ''
+            if saxis.lower() == 'x':
+                self.lonvar = vv
+    # fifth sweep: same as first but units can be "degrees"
     if not self.latvar:
         for vv in self.fi.variables:
             try:
@@ -354,7 +377,7 @@ def analyse_netcdf(self):
                     sunit = ''
                 if sunit.lower() == 'degrees':
                     self.lonvar = vv
-    # fifth sweep: same as second but units can be "degrees"
+    # sixth sweep: same as second but units can be "degrees"
     if not self.latvar:
         for vv in self.fi.variables:
             sname = self.fi.variables[vv].name
@@ -375,7 +398,7 @@ def analyse_netcdf(self):
                     sunit = ''
                 if sunit.lower() == 'degrees':
                     self.lonvar = vv
-    # sixth sweep: same as third but units can be "degrees"
+    # seventh sweep: same as third but units can be "degrees"
     if not self.latvar:
         for vv in self.fi.variables:
             sname = self.fi.variables[vv].name
@@ -403,7 +426,7 @@ def analyse_netcdf(self):
     self.latdim = ''
     self.londim = ''
     if self.latvar:
-        latshape = self.fi.variables[self.lonvar].shape
+        latshape = self.fi.variables[self.latvar].shape
         if (len(latshape) < 1) or (len(latshape) > 2):
             estr  = 'Something went wrong determining lat/lon:'
             estr += ' latitude variable is not 1D or 2D.'
@@ -411,11 +434,7 @@ def analyse_netcdf(self):
             estr = 'latitude variable with dimensions:'
             ldim = self.fi.variables[self.latvar].dimensions
             print(estr, self.latvar, ldim)
-            estr = 'longitude variable with dimensions:'
-            ldim = self.fi.variables[self.lonvar].dimensions
-            print(estr, self.lonvar, ldim)
             self.latvar = ''
-            self.lonvar = ''
         else:
             self.latdim = self.fi.variables[self.latvar].dimensions[0]
     if self.lonvar:
@@ -428,22 +447,18 @@ def analyse_netcdf(self):
             estr  = 'Something went wrong determining lat/lon:'
             estr += ' longitude variable is not 1D or 2D.'
             print(estr)
-            estr = 'latitude variable with dimensions:'
-            ldim = self.fi.variables[self.latvar].dimensions
-            print(estr, self.latvar, ldim)
             estr = 'longitude variable with dimensions:'
             ldim = self.fi.variables[self.lonvar].dimensions
             print(estr, self.lonvar, ldim)
-            self.latvar = ''
             self.lonvar = ''
     #
     # add units to lat/lon name
     if self.latvar:
         idim = tuple(zip_dim_name_length(self.fi.variables[self.latvar]))
-        self.latvar = self.latvar + ' ' + SEPCHAR + str(idim)
+        self.latvar = self.latvar + ' ' + str(idim)
     if self.lonvar:
         idim = tuple(zip_dim_name_length(self.fi.variables[self.lonvar]))
-        self.lonvar = self.lonvar + ' ' + SEPCHAR + str(idim)
+        self.lonvar = self.lonvar + ' ' + str(idim)
 
 
 #
@@ -720,6 +735,7 @@ def set_dim_var(self):
                               state=tk.NORMAL)
             if ((vv.dimensions[i] != self.latdim) and
                 (vv.dimensions[i] != self.londim) and
+                (vv.dimensions[i] != self.dunlim) and
                 (nall <= 1) and (vv.shape[i] > 1)):
                 nall += 1
                 self.vdval[i].set('all')
