@@ -9,18 +9,8 @@ This module was written by Matthias Cuntz while at Institut National de
 Recherche pour l'Agriculture, l'Alimentation et l'Environnement (INRAE), Nancy,
 France.
 
-Copyright (c) 2020-2021 Matthias Cuntz - mc (at) macu (dot) de
-
-Released under the MIT License; see LICENSE file for details.
-
-History:
-
-* Written Nov-Dec 2020 by Matthias Cuntz (mc (at) macu (dot) de)
-* Separate Tk() and Toplevel() widgets to communicate via Tk() between windows,
-  Jan 2021, Matthias Cuntz
-* Set titlebar and taskbar icon only if "standalone" not in ipython or jupyter,
-  May 2021, Matthias Cuntz
-* Different themes for different OS, May 2021, Matthias Cuntz
+:copyright: Copyright 2020-2021 Matthias Cuntz - mc (at) macu (dot) de
+:license: MIT License, see LICENSE for details.
 
 .. moduleauthor:: Matthias Cuntz
 
@@ -28,6 +18,16 @@ The following functions are provided:
 
 .. autosummary::
    ncvue
+
+History
+    * Written Nov-Dec 2020 by Matthias Cuntz (mc (at) macu (dot) de)
+    * Separate Tk() and Toplevel() widgets to communicate via Tk() between
+      windows, Jan 2021, Matthias Cuntz
+    * Set titlebar and taskbar icon only if "standalone" not in ipython or
+      jupyter, May 2021, Matthias Cuntz
+    * Different themes for different OS, May 2021, Matthias Cuntz
+    * Font size 13 on Windows for plots, Jun 2021, Matthias Cuntz
+
 """
 from __future__ import absolute_import, division, print_function
 import sys
@@ -43,6 +43,9 @@ import numpy as np
 import netCDF4 as nc
 from .ncvmethods import analyse_netcdf
 from .ncvmain import ncvMain
+import matplotlib as mpl
+mpl.use('TkAgg')
+from matplotlib import pyplot as plt
 
 
 __all__ = ['ncvue']
@@ -68,7 +71,7 @@ def ncvue(ncfile='', miss=np.nan):
         from ctypes import windll
         windll.shcore.SetProcessDpiAwareness(1)
 
-    # if macOS app then _MEIPASS is set
+    # Pyinstaller sets _MEIPASS if macOS app
     bundle_dir = getattr(sys, '_MEIPASS',
                          os.path.abspath(os.path.dirname(__file__)))
 
@@ -83,22 +86,52 @@ def ncvue(ncfile='', miss=np.nan):
     # print(style.theme_names(), style.theme_use())
     if ios == 'Darwin':
         theme = 'aqua'
+        style = ttk.Style()
+        style.theme_use(theme)
     elif ios == 'Windows':
-        # # style packages
-        # # top.tk.call('lappend', 'auto_path',
-        # #             bundle_dir + '/themes/awthemes-10.3.0')
-        # # theme = 'awlight'  # 'awlight', 'awdark'
-        # # top.tk.call('package', 'require', theme)
+        top.option_add("*Font", "Helvetica 10")
+        plt.rc('font', size=13)
+        # standard Windows themes
+        # ('winnative', 'clam', 'alt', 'default', 'classic', 'vista', 'xpnative')
+        # theme = 'vista'
+        # style = ttk.Style()
+        # style.theme_use(theme)
+
+        # style packages
+        # Download from https://sourceforge.net/projects/tcl-awthemes/
+        # top.tk.call('lappend', 'auto_path',
+        #             bundle_dir + '/themes/awthemes-10.3.2')
+        # theme = 'awdark'  # 'awlight', 'awdark'
+        # top.tk.call('package', 'require', theme)
+        # style = ttk.Style()
+        # style.theme_use(theme)
 
         # single file styles
+        # 'azure' and 'azure-dark' v1.x, 'Breeze'
         # top.tk.call('source', bundle_dir + '/themes/breeze/breeze.tcl')
-        top.tk.call('source', bundle_dir + '/themes/azure/azure.tcl')
-        # top.tk.call('source', bundle_dir + '/themes/azure/azure-dark.tcl')
-        theme = 'azure'  # 'azure', 'azure-dark', 'Breeze'
+        # theme = 'Breeze'
+        # top.tk.call('source', bundle_dir + '/themes/azure-1.3/azure.tcl')
+        # theme = 'azure'
+        # top.tk.call('source', bundle_dir + '/themes/azure-1.3/azure-dark.tcl')
+        # theme = 'azure-dark'
+        # style = ttk.Style()
+        # style.theme_use(theme)
+
+        # 'azure' v2.x, 'sun-valley', 'forest' of rdbende
+        top.tk.call('source', bundle_dir + '/themes/azure-2.0/azure.tcl')
+        # top.tk.call('source', bundle_dir + '/themes/sun-valley-1.0/sun-valley.tcl')
+        theme = 'light'  # light, dark
+        top.tk.call("set_theme", theme)
     elif ios == 'Linux':
-        theme = 'clam'  # 'clam', 'alt', 'default', 'classic'
-    style = ttk.Style()
-    style.theme_use(theme)
+        # standard Linux schemes
+        # theme = 'clam'  # 'clam', 'alt', 'default', 'classic'
+        # style = ttk.Style()
+        # style.theme_use(theme)
+
+        # 'azure' v2.x, 'sun-valley', 'forest' of rdbende
+        top.tk.call('source', bundle_dir + '/themes/azure-2.0/azure.tcl')
+        theme = 'light'  # light, dark
+        top.tk.call("set_theme", theme)
 
     # set titlebar and taskbar icon only if "standalone",
     # i.e. not ipython or jupyter
