@@ -9,27 +9,8 @@ This module was written by Matthias Cuntz while at Institut National de
 Recherche pour l'Agriculture, l'Alimentation et l'Environnement (INRAE), Nancy,
 France.
 
-Copyright (c) 2020-2021 Matthias Cuntz - mc (at) macu (dot) de
-
-Released under the MIT License; see LICENSE file for details.
-
-History:
-
-* Written Nov-Dec 2020 by Matthias Cuntz (mc (at) macu (dot) de)
-* General get_slice function from individual methods for x, y, y2, z,
-  Dec 2020, Matthias Cuntz
-* Added arithmetics to apply on axis/dimensions such as mean, std, etc.,
-  Dec 2020, Matthias Cuntz
-* Added clone_ncvmain, removing its own module, Dec 2020, Matthias Cuntz
-* added SEPCHAR and DIMMETHODS, Jan 2021, Matthias Cuntz
-* pass only ncvMain widget to clone_ncvmain, Jan 2021, Matthias Cuntz
-* pass only root widget to clone_ncvmain, Jan 2021, Matthias Cuntz
-* set correct missing value for date variable in numpy's datetime64[ms] format
-  May 2021, Matthias Cuntz
-* added format_coord functions for scatter, contour, and map,
-  May 2021, Matthias Cuntz
-* replaced add_cyclic_point with add_cyclic as submitted to cartopy,
-  Jun 2021, Matthias Cuntz
+:copyright: Copyright 2020-2021 Matthias Cuntz - mc (at) macu (dot) de
+:license: MIT License, see LICENSE for details.
 
 .. moduleauthor:: Matthias Cuntz
 
@@ -37,7 +18,6 @@ The following functions are provided:
 
 .. autosummary::
    DIMMETHODS
-   SEPCHAR
    add_cyclic
    clone_ncvmain
    format_coord_contour
@@ -50,16 +30,34 @@ The following functions are provided:
    spinbox_values
    vardim2var
    zip_dim_name_length
+
+History
+    * Written Nov-Dec 2020 by Matthias Cuntz (mc (at) macu (dot) de)
+    * General get_slice function from individual methods for x, y, y2, z,
+      Dec 2020, Matthias Cuntz
+    * Added arithmetics to apply on axis/dimensions such as mean, std, etc.,
+      Dec 2020, Matthias Cuntz
+    * Added clone_ncvmain, removing its own module, Dec 2020, Matthias Cuntz
+    * added SEPCHAR and DIMMETHODS, Jan 2021, Matthias Cuntz
+    * pass only ncvMain widget to clone_ncvmain, Jan 2021, Matthias Cuntz
+    * pass only root widget to clone_ncvmain, Jan 2021, Matthias Cuntz
+    * set correct missing value for date variable in numpy's datetime64[ms]
+      format May 2021, Matthias Cuntz
+    * added format_coord functions for scatter, contour, and map,
+      May 2021, Matthias Cuntz
+    * replaced add_cyclic_point with add_cyclic as submitted to cartopy,
+      Jun 2021, Matthias Cuntz
+    * removed SEPCHAR, Jun 2021, Matthias Cuntz
+
 """
 from __future__ import absolute_import, division, print_function
 import tkinter as tk
 import numpy as np
 import matplotlib.dates as mpld
 import cartopy.crs as ccrs
-import platform
 
 
-__all__ = ['DIMMETHODS', 'SEPCHAR',
+__all__ = ['DIMMETHODS',
            'add_cyclic', 'clone_ncvmain',
            'format_coord_contour', 'format_coord_map', 'format_coord_scatter',
            'get_slice',
@@ -81,56 +79,6 @@ median - 50-percentile
 var - variance
 """
 
-ios = platform.system()
-if ios == 'Darwin':
-    # SEPCHAR = chr(6)
-    SEPCHAR = chr(31)
-elif ios == 'Java':
-    SEPCHAR = chr(31)
-elif ios == 'Linux':
-    SEPCHAR = chr(9)
-elif ios == 'Windows':
-    SEPCHAR = chr(31)
-else:
-    SEPCHAR = chr(31)
-"""
-Invisible character to split strings.
-
-Name (Code) Decimal
-Null (NUL) 0
-Start of Heading (SOH) 1
-Start of Text (STX) 2
-End of Text (ETX) 3
-End of Transmit (EOT) 4
-Enquiry (ENQ) 5
-Acknowledge (ACK) 6
-Bell (BEL) 7
-Back Space (BS) 8
-Horizontal Tab (TAB) 9
-Line Feed (LF) 10
-Vertical Tab (VT) 11
-Form Feed (FF) 12
-Carriage Return (CR) 13
-Shift Out (SO) 14
-Shift In (SI) 15
-Data Line Escape (DLE) 16
-Device Control 1 (DC1) 17
-Device Control 2 (DC2) 18
-Device Control 3 (DC3) 19
-Device Control 4 (DC4) 20
-Negative Acknowledge (NAK) 21
-Synchronous Idle (SYN) 22
-End of Transmit Block (ETB) 23
-Cancel (CAN) 24
-End of Medium (EM) 25
-Substitute (SUB) 26
-Escape (ESC) 27
-File Separator (FS) 28
-Group Separator (GS) 29
-Record Separator (RS) 30
-Unit Separator (US) 31
-"""
-
 
 def _add_cyclic_data(data, axis=-1):
     """
@@ -858,7 +806,7 @@ def vardim2var(vardim):
     >>> vardim2var('latitude (lat=32,lon=64)')
     latitude
     """
-    return vardim.split(SEPCHAR)[0].rstrip()
+    return vardim[0:vardim.rfind('(')].rstrip()
 
 
 def zip_dim_name_length(ncvar):
